<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Models\Order;
use App\Models\OrderItem;
use App\Models\Payment;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class ReportsController extends Controller
{
    /**
     * Genel istatistikleri getir
     */
    public function getStatistics()
    {
            try {
                $today = Carbon::today();
                $startOfMonth = Carbon::now()->startOfMonth();
                $lastMonth = Carbon::now()->subMonth()->startOfMonth();

                // Günlük gelir
                $dailyIncome = Payment::whereDate('payment_date', $today)->sum('amount');
                $yesterdayIncome = Payment::whereDate('payment_date', $today->copy()->subDay())->sum('amount');
                $dailyIncreasePercentage = $yesterdayIncome > 0
                    ? (($dailyIncome - $yesterdayIncome) / $yesterdayIncome) * 100
                    : 0;

                // Aylık gelir
                $monthlyIncome = Payment::whereMonth('payment_date', $today->month)
                                      ->whereYear('payment_date', $today->year)
                                      ->sum('amount');
                $lastMonthIncome = Payment::whereMonth('payment_date', $lastMonth->month)
                                        ->whereYear('payment_date', $lastMonth->year)
                                        ->sum('amount');
                $monthlyIncreasePercentage = $lastMonthIncome > 0
                    ? (($monthlyIncome - $lastMonthIncome) / $lastMonthIncome) * 100
                    : 0;

                // Sipariş sayıları
                $totalOrders = Order::where('is_paid', true)->count();
                $monthlyOrders = Order::where('is_paid', true)
                                    ->whereMonth('created_at', $today->month)
                                    ->whereYear('created_at', $today->year)
                                    ->count();

                // En çok satanlar (bugün)
                $topSellingToday = OrderItem::select(
                    'products.name',
                    'products.price',
                    DB::raw('SUM(order_items.quantity) as total_quantity'),
                    DB::raw('SUM(order_items.quantity * products.price) as total_amount')
                )
                ->join('products', 'order_items.product_id', '=', 'products.id')
                ->join('orders', 'order_items.order_id', '=', 'orders.id')
                ->whereDate('order_items.added_at', $today)
                ->where('orders.is_paid', true)
                ->groupBy('products.id', 'products.name', 'products.price')
                ->orderBy('total_quantity', 'desc')
                ->limit(5)
                ->get();

                return response()->json([
                    'status' => true,
                    'data' => [
                        'daily_income' => [
                            'amount' => $dailyIncome,
                            'increase_percentage' => round($dailyIncreasePercentage, 1)
                        ],
                        'monthly_income' => [
                            'amount' => $monthlyIncome,
                            'increase_percentage' => round($monthlyIncreasePercentage, 1)
                        ],
                        'orders' => [
                            'total' => $totalOrders,
                            'monthly' => $monthlyOrders
                        ],
                        'top_selling_today' => $topSellingToday
                    ]
                ]);

            } catch (\Exception $e) {
                return response()->json([
                    'status' => false,
                    'message' => 'İstatistikler getirilirken hata oluştu',
                'error' => $e->getMessage()
            ], 500);
        }
    }

    /**
     * Detaylı satış raporu
     */
    public function getSalesReport(Request $request)
    {

        try {
            $startDate = $request->input('start_date', Carbon::today());
            $endDate = $request->input('end_date', Carbon::today());

            $sales = Payment::with('user')
                ->whereBetween('payment_date', [$startDate, $endDate])
                ->select(
                    DB::raw('DATE(payment_date) as date'),
                    DB::raw('COUNT(*) as total_orders'),
                    DB::raw('SUM(amount) as total_amount')
                )
                ->groupBy('date')
                ->orderBy('date')
                ->get();

            return response()->json([
                'status' => true,
                'data' => [
                    'sales' => $sales,
                    'waiter' => $sales->first()->user->name
                ]
            ]);

        } catch (\Exception $e) {
            return response()->json([
                'status' => false,
                'message' => 'Satış raporu getirilirken hata oluştu',
                'error' => $e->getMessage()
            ], 500);
        }
    }
}
