<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Models\Order;
use App\Models\OrderItem;
use App\Models\Table;
use App\Enums\TableStatus;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use App\Models\Payment;
use PDF;
use Mike42\Escpos\PrintConnectors\NetworkPrintConnector;
    use Mike42\Escpos\Printer;
use App\Models\KitchenOrder;
    use Illuminate\Container\Attributes\Auth;

class TableAddOrderController extends Controller
{
    /**
     * Masaya sipariş ekleme
     */
    public function addOrder(Request $request, $tableId)
    {
        try {
            $validator = Validator::make($request->all(), [
                'products' => 'required|array',
                'products.*.product_id' => 'required|exists:products,id',
                'products.*.quantity' => 'required|integer|min:1'
            ]);

            if ($validator->fails()) {
                return response()->json([
                    'status' => false,
                    'message' => 'Doğrulama hatası',
                    'errors' => $validator->errors()
                ], 422);
            }

            $table = Table::findOrFail($tableId);

            DB::beginTransaction();

            // Aktif sipariş var mı kontrol et
            $order = Order::where('table_id', $tableId)
                ->where('is_paid', false)
                ->first();

            // Yoksa yeni sipariş oluştur
            if (!$order) {
                $order = Order::create([
                    'table_id' => $tableId,
                    'is_paid' => false,
                    'total_price' => 0
                ]);
            }

            $totalPrice = 0;

            // Siparişleri ekle
            foreach ($request->products as $item) {
                $orderItem = OrderItem::create([
                    'order_id' => $order->id,
                    'product_id' => $item['product_id'],
                    'quantity' => $item['quantity']
                ]);

                $totalPrice += $orderItem->product->price * $item['quantity'];

                // Eğer ürün mutfağa gidecekse mutfak siparişi oluştur
                if ($orderItem->product->kitchen_print) {
                    KitchenOrder::create([
                        'order_id' => $order->id,
                        'order_item_id' => $orderItem->id,
                        'product_id' => $item['product_id'],
                        'table_id' => $tableId,
                        'quantity' => $item['quantity'],
                        'status' => 'pending'
                    ]);
                }
            }

            // Toplam fiyatı güncelle
            $order->total_price = $order->total_price + $totalPrice;
            $order->save();

            // Masa durumunu güncelle
            $table->update([
                'status' => TableStatus::ACTIVE,
                'date' => now(),
                'total_price' => $order->total_price,
                'product_count' => OrderItem::where('order_id', $order->id)->sum('quantity')
            ]);

            DB::commit();

            return response()->json([
                'status' => true,
                'message' => 'Sipariş başarıyla eklendi',
                'order' => $order->load(['orderItems.product', 'kitchenOrders'])
            ], 200);
        } catch (\Exception $e) {
            DB::rollBack();
            return response()->json([
                'status' => false,
                'message' => 'Sipariş ekleme başarısız',
                'error' => $e->getMessage()
            ], 500);
        }
    }

    /**
     * Masa sipariş detaylarını getir
     */
    public function getOrderDetails($tableId)
    {
        try {
            $table = Table::findOrFail($tableId);
            $order = Order::where('table_id', $tableId)
                ->where('is_paid', false)
                ->where('archived', false)
                ->with('orderItems.product')
                ->first();

            if (!$order) {
                return response()->json([
                    'status' => false,
                    'message' => 'Aktif sipariş bulunamadı'
                ], 404);
            }

            return response()->json([
                'status' => true,
                'message' => 'Sipariş detayları başarıyla getirildi',
                'table' => $table,
                'order' => $order
            ], 200);
        } catch (\Exception $e) {
            return response()->json([
                'status' => false,
                'message' => 'Sipariş detayları getirilemedi',
                'error' => $e->getMessage()
            ], 500);
        }
    }

    /**
     * Masa durumunu kontrol et
     */
    public function checkTableStatus($tableId)
    {
        try {
            $table = Table::findOrFail($tableId);
            $lastOrderTime = Carbon::parse($table->date);
            $now = Carbon::now();

            $minutesPassed = $lastOrderTime->diffInMinutes($now);

            return response()->json([
                'status' => true,
                'message' => 'Masa durumu',
                'data' => [
                    'table_status' => $table->status,
                    'minutes_passed' => $minutesPassed,
                    'last_order_time' => $table->date,
                ],
                'table' => $table
            ], 200);
        } catch (\Exception $e) {
            return response()->json([
                'status' => false,
                'message' => 'Masa durumu kontrol edilemedi',
                'error' => $e->getMessage()
            ], 500);
        }
    }

    /**
     * Masadan ödeme al
     */
    public function takePayment($tableId)
    {
        try {
            DB::beginTransaction();

            $table = Table::findOrFail($tableId);
            $order = Order::where('table_id', $tableId)
                ->where('is_paid', false)
                ->with('orderItems.product')
                ->first();

            if (!$order) {
                return response()->json([
                    'status' => false,
                    'message' => 'Aktif sipariş bulunamadı'
                ], 404);
            }

            // Ödeme kaydını oluştur
            $payment = Payment::create([
                'table_id' => $tableId,
                'user_id' => auth()->user()->id,
                'order_id' => $order->id,
                'amount' => $order->total_price,
                'payment_date' => now()
            ]);

            // Siparişi ödenmiş olarak işaretle ve arşivle
            $order->update([
                'is_paid' => true,
                'archived' => true,
                'archived_at' => now()
            ]);

            // Masayı sıfırla
            $table->update([
                'status' => TableStatus::EMPTY,
                'total_price' => 0,
                'product_count' => 0,
                'date' => null
            ]);

            DB::commit();

            return response()->json([
                'status' => true,
                'message' => 'Ödeme başarıyla alındı',
                'payment' => $payment,
                'order' => $order
            ], 200);
        } catch (\Exception $e) {
            DB::rollBack();
            return response()->json([
                'status' => false,
                'message' => 'Ödeme alınırken hata oluştu',
                'error' => $e->getMessage()
            ], 500);
        }
    }

    /**
     * 15 dakika sipariş vermeyen masaları kontrol et
     */
    public function checkInactiveTables()
    {
        try {
            $tables = Table::where('status', TableStatus::ACTIVE)
                ->whereNotNull('date')
                ->get();

            $updatedTables = [];
            foreach ($tables as $table) {
                $lastOrderTime = Carbon::parse($table->date);
                $minutesPassed = $lastOrderTime->diffInMinutes(now());

                if ($minutesPassed >= 15) {
                    $table->update([
                        'status' => TableStatus::WAITING
                    ]);
                    $updatedTables[] = $table->fresh();
                }
            }

            return response()->json([
                'status' => true,
                'message' => 'Masalar kontrol edildi',
                'updated_tables' => $updatedTables
            ]);

        } catch (\Exception $e) {
            return response()->json([
                'status' => false,
                'message' => 'Masalar kontrol edilirken hata oluştu',
                'error' => $e->getMessage()
            ], 500);
        }
    }

    /**
     * Masa aktarma işlemi
     */
    public function transferTable($sourceTableId, $targetTableId)
    {
        try {
            DB::beginTransaction();

            // Kaynak ve hedef masaları bul
            $sourceTable = Table::findOrFail($sourceTableId);
            $targetTable = Table::findOrFail($targetTableId);

            // Kaynak masadaki aktif siparişi bul
            $sourceOrder = Order::where('table_id', $sourceTableId)
                ->where('is_paid', false)
                ->first();

            if (!$sourceOrder) {
                return response()->json([
                    'status' => false,
                    'message' => 'Aktarılacak aktif sipariş bulunamadı'
                ], 404);
            }

            // Hedef masada aktif sipariş var mı kontrol et
            $targetOrder = Order::where('table_id', $targetTableId)
                ->where('is_paid', false)
                ->first();

            if ($targetOrder) {
                // Kaynak masadaki sipariş ürünlerini hedef masaya aktar
                foreach ($sourceOrder->orderItems as $item) {
                    OrderItem::create([
                        'order_id' => $targetOrder->id,
                        'product_id' => $item->product_id,
                        'quantity' => $item->quantity
                    ]);
                }

                // Hedef masanın toplam fiyatını güncelle
                $targetOrder->total_price += $sourceOrder->total_price;
                $targetOrder->save();

                // Kaynak siparişi arşivle
                $sourceOrder->update([
                    'is_paid' => true,
                    'archived' => true,
                    'archived_at' => now()
                ]);
            } else {
                // Hedef masada sipariş yoksa, kaynaktaki siparişi transfer et
                $sourceOrder->update([
                    'table_id' => $targetTableId
                ]);
            }

            // Hedef masayı güncelle
            $newTotalPrice = $targetOrder
                ? $targetOrder->total_price
                : $sourceOrder->total_price;

            $newProductCount = OrderItem::where('order_id', $targetOrder ? $targetOrder->id : $sourceOrder->id)
                ->sum('quantity');

            $targetTable->update([
                'status' => TableStatus::ACTIVE,
                'total_price' => $newTotalPrice,
                'product_count' => $newProductCount,
                'date' => now()
            ]);

            // Kaynak masayı sıfırla
            $sourceTable->update([
                'status' => TableStatus::EMPTY,
                'total_price' => 0,
                'product_count' => 0,
                'date' => null
            ]);

            DB::commit();

            $finalOrder = $targetOrder ?? $sourceOrder;

            return response()->json([
                'status' => true,
                'message' => 'Masa başarıyla aktarıldı',
                'source_table' => $sourceTable,
                'target_table' => $targetTable,
                'order' => $finalOrder->fresh()->load('orderItems.product')
            ], 200);

        } catch (\Exception $e) {
            DB::rollBack();
            return response()->json([
                'status' => false,
                'message' => 'Masa aktarma işlemi başarısız',
                'error' => $e->getMessage()
            ], 500);
        }
    }

    /**
     * Sipariş çıktısı alma
     */
    public function getOrderReceipt($orderId)
    {
        try {
            $order = Order::with(['orderItems.product', 'table'])
                ->findOrFail($orderId);

            // Fiş içeriğini oluştur
            $output = "";
            $output .= str_repeat("=", 48) . "\n";
            $output .= str_pad("SİPARİŞ FİŞİ", 48, " ", STR_PAD_BOTH) . "\n";
            $output .= str_repeat("=", 48) . "\n\n";

            // İşletme bilgileri
            $output .= str_pad("CAFE ADISYON", 48, " ", STR_PAD_BOTH) . "\n";
            $output .= str_pad("Tel: 0212 XXX XX XX", 48, " ", STR_PAD_BOTH) . "\n";
            $output .= str_repeat("-", 48) . "\n\n";

            // Sipariş detayları
            $output .= sprintf("%-12s: #%s\n", "Sipariş No", str_pad($order->id, 20, " ", STR_PAD_LEFT));
            $output .= sprintf("%-12s: %s\n", "Masa", str_pad($order->table->name, 20, " ", STR_PAD_LEFT));
            $output .= sprintf("%-12s: %s\n", "Tarih", str_pad($order->created_at->format('d.m.Y H:i'), 20, " ", STR_PAD_LEFT));
            $output .= str_repeat("-", 48) . "\n\n";

            // Başlıklar
            $output .= sprintf("%-25s %5s %8s %8s\n", "Ürün", "Adet", "Fiyat", "Toplam");
            $output .= str_repeat("-", 48) . "\n";

            // Ürünler
            foreach ($order->orderItems as $item) {
                $output .= sprintf(
                    "%-25s %2dx %8s %8s\n",
                    mb_substr($item->product->name, 0, 25),
                    $item->quantity,
                    number_format($item->product->price, 2),
                    number_format($item->quantity * $item->product->price, 2)
                );
            }

            // Alt toplam ve toplam
            $output .= "\n" . str_repeat("-", 48) . "\n";
            $output .= str_pad("ARA TOPLAM: " . number_format($order->total_price, 2) . " TL", 48, " ", STR_PAD_LEFT) . "\n";
            $output .= str_pad("KDV (%8): " . number_format($order->total_price * 0.08, 2) . " TL", 48, " ", STR_PAD_LEFT) . "\n";
            $output .= str_pad("TOPLAM: " . number_format($order->total_price, 2) . " TL", 48, " ", STR_PAD_LEFT) . "\n";
            $output .= str_repeat("=", 48) . "\n\n";

            // Alt bilgi
            $output .= str_pad("Bizi tercih ettiğiniz için", 48, " ", STR_PAD_BOTH) . "\n";
            $output .= str_pad("teşekkür ederiz!", 48, " ", STR_PAD_BOTH) . "\n";
            $output .= str_repeat("=", 48);

            // Dosyaya kaydet
            $filename = 'receipt_' . $order->id . '_' . time() . '.txt';
            \Storage::disk('public')->put('receipts/' . $filename, $output);

            /* Yazıcı Kodu - Test için devre dışı
            try {
                $connector = new NetworkPrintConnector("192.168.1.x", 9100);
                $printer = new Printer($connector);

                // Yazıcı ayarları
                $printer->setJustification(Printer::JUSTIFY_CENTER);
                $printer->setTextSize(2, 2);
                $printer->text("SİPARİŞ FİŞİ\n\n");
                $printer->setTextSize(1, 1);

                // İşletme bilgileri
                $printer->text("CAFE ADISYON\n");
                $printer->text("Tel: 0212 XXX XX XX\n");
                $printer->feed();

                // Çizgi
                $printer->text(str_repeat("-", 48) . "\n");

                // Sipariş detayları
                $printer->setJustification(Printer::JUSTIFY_LEFT);
                $printer->text(sprintf("Sipariş No : #%s\n", $order->id));
                $printer->text(sprintf("Masa       : %s\n", $order->table->name));
                $printer->text(sprintf("Tarih      : %s\n", $order->created_at->format('d.m.Y H:i')));
                $printer->text(str_repeat("-", 48) . "\n");

                // Başlıklar
                $printer->text(sprintf("%-25s %5s %8s %8s\n", "Ürün", "Adet", "Fiyat", "Toplam"));
                $printer->text(str_repeat("-", 48) . "\n");

                // Ürünler
                foreach ($order->orderItems as $item) {
                    $printer->text(sprintf(
                        "%-25s %2dx %8s %8s\n",
                        mb_substr($item->product->name, 0, 25),
                        $item->quantity,
                        number_format($item->product->price, 2),
                        number_format($item->quantity * $item->product->price, 2)
                    ));
                }

                // Toplamlar
                $printer->feed();
                $printer->setJustification(Printer::JUSTIFY_RIGHT);
                $printer->text(sprintf("ARA TOPLAM: %s TL\n", number_format($order->total_price, 2)));
                $printer->text(sprintf("KDV (%%8)  : %s TL\n", number_format($order->total_price * 0.08, 2)));
                $printer->text(sprintf("TOPLAM     : %s TL\n", number_format($order->total_price, 2)));

                // Alt bilgi
                $printer->feed(2);
                $printer->setJustification(Printer::JUSTIFY_CENTER);
                $printer->text("Bizi tercih ettiğiniz için\n");
                $printer->text("teşekkür ederiz!\n");

                // QR Kod (isteğe bağlı)
                // $printer->qrCode("https://example.com/order/" . $order->id);

                // Kesme
                $printer->cut();
                $printer->close();
            } catch (\Exception $e) {
                // Yazıcı hatası durumunda sessizce devam et
                \Log::error('Printer Error: ' . $e->getMessage());
            }
            */

            return response()->json([
                'status' => true,
                'message' => 'Fiş oluşturuldu',
                'receipt' => $output,
                'file_url' => \Storage::disk('public')->url('receipts/' . $filename)
            ]);

        } catch (\Exception $e) {
            return response()->json([
                'status' => false,
                'message' => 'Fiş oluşturulurken hata oluştu',
                'error' => $e->getMessage()
            ], 500);
        }
    }

    /**
     * Günlük rapor çıktısı alma
     */
    public function getDailyReceipt(Request $request)
    {
        try {
            $date = $request->date ?? now()->format('Y-m-d');

            $orders = Order::with(['orderItems.product', 'table'])
                ->whereDate('created_at', $date)
                ->where('is_paid', true)
                ->get();

            // Fiş içeriğini oluştur
            $output = "";
            $output .= str_repeat("=", 48) . "\n";
            $output .= str_pad("GÜNLÜK RAPOR", 48, " ", STR_PAD_BOTH) . "\n";
            $output .= str_repeat("=", 48) . "\n\n";

            // İşletme bilgileri
            $output .= str_pad("CAFE ADISYON", 48, " ", STR_PAD_BOTH) . "\n";
            $output .= str_pad("Tel: 0212 XXX XX XX", 48, " ", STR_PAD_BOTH) . "\n";
            $output .= str_repeat("-", 48) . "\n\n";

            // Rapor detayları
            $output .= sprintf("%-12s: %s\n", "Tarih", Carbon::parse($date)->format('d.m.Y'));
            $output .= str_repeat("-", 48) . "\n\n";

            // Özet bilgiler
            $output .= sprintf("%-20s: %d\n", "Toplam Sipariş", $orders->count());
            $output .= sprintf("%-20s: %s TL\n", "Toplam Satış", number_format($orders->sum('total_price'), 2));
            $output .= str_repeat("-", 48) . "\n\n";

            // Başlıklar
            $output .= sprintf("%-8s %-15s %8s %12s\n", "Sip.No", "Masa", "Saat", "Tutar");
            $output .= str_repeat("-", 48) . "\n";

            // Siparişler
            foreach ($orders as $order) {
                $output .= sprintf(
                    "#%-7s %-15s %8s %11s TL\n",
                    $order->id,
                    mb_substr($order->table->name, 0, 15),
                    $order->created_at->format('H:i'),
                    number_format($order->total_price, 2)
                );
            }

            $output .= "\n" . str_repeat("-", 48) . "\n";
            $output .= str_pad("RAPOR SONU", 48, " ", STR_PAD_BOTH) . "\n";
            $output .= str_repeat("=", 48);

            // Dosyaya kaydet
            $filename = 'daily_report_' . $date . '_' . time() . '.txt';
            \Storage::disk('public')->put('receipts/' . $filename, $output);

            /* Yazıcı Kodu - Test için devre dışı
            try {
                $connector = new NetworkPrintConnector("192.168.1.x", 9100);
                $printer = new Printer($connector);

                // Başlık
                $printer->setJustification(Printer::JUSTIFY_CENTER);
                $printer->setEmphasis(true);
                $printer->setTextSize(2, 2);
                $printer->text("GÜNLÜK RAPOR\n\n");

                $printer->setTextSize(1, 1);
                $printer->text("CAFE ADISYON\n");
                $printer->text("Tel: 0212 XXX XX XX\n");
                $printer->setEmphasis(false);
                $printer->feed();

                // Tarih
                $printer->setJustification(Printer::JUSTIFY_LEFT);
                $printer->text("Tarih: " . Carbon::parse($date)->format('d.m.Y') . "\n\n");

                // Özet Bilgiler
                $printer->setEmphasis(true);
                $printer->text("ÖZET BİLGİLER\n");
                $printer->setEmphasis(false);
                $printer->text(sprintf("Toplam Sipariş : %d\n", $orders->count()));
                $printer->text(sprintf("Toplam Satış   : %s TL\n", number_format($orders->sum('total_price'), 2)));
                $printer->text(str_repeat("-", 48) . "\n\n");

                // Siparişler Tablosu
                $printer->setEmphasis(true);
                $printer->text("SİPARİŞ DETAYLARI\n");
                $printer->setEmphasis(false);
                $printer->text(sprintf("%-8s %-15s %8s %12s\n", "Sip.No", "Masa", "Saat", "Tutar"));
                $printer->text(str_repeat("-", 48) . "\n");

                foreach ($orders as $order) {
                    $printer->text(sprintf(
                        "#%-7s %-15s %8s %11s TL\n",
                        $order->id,
                        mb_substr($order->table->name, 0, 15),
                        $order->created_at->format('H:i'),
                        number_format($order->total_price, 2)
                    ));
                }

                // Alt Bilgi
                $printer->feed(2);
                $printer->setJustification(Printer::JUSTIFY_CENTER);
                $printer->text(str_repeat("=", 48) . "\n");
                $printer->text("RAPOR SONU\n");
                $printer->text(date('d/m/Y H:i:s') . "\n");

                // Kesme
                $printer->cut();
                $printer->close();
            } catch (\Exception $e) {
                // Yazıcı hatası durumunda sessizce devam et
                \Log::error('Printer Error: ' . $e->getMessage());
            }
            */

            return response()->json([
                'status' => true,
                'message' => 'Günlük rapor oluşturuldu',
                'receipt' => $output,
                'file_url' => \Storage::disk('public')->url('receipts/' . $filename)
            ]);

        } catch (\Exception $e) {
            return response()->json([
                'status' => false,
                'message' => 'Rapor oluşturulurken hata oluştu',
                'error' => $e->getMessage()
            ], 500);
        }
    }
}
