<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Models\Table;
use Illuminate\Support\Facades\Validator;
use Illuminate\Http\Request;
use App\Models\TableStatus;
use Illuminate\Support\Facades\DB;
use App\Models\KitchenOrder;
use App\Models\OrderItem;
use App\Models\Payment;
use App\Models\Order;
use App\Models\QrOrder;
use App\Models\WaiterCall;
use Illuminate\Support\Facades\Log;

class TableController extends Controller
{

    /**
     * index
     *
     * @return void
     */
    public function index()
    {
        try {
            $tables = Table::all();
            return response()->json(['status' => true, 'message' => 'Tables fetched successfully', 'tables' => $tables], 200);
        } catch (\Exception $e) {
            return response()->json(['status' => false, 'message' => 'Tables fetching failed', 'errors' => $e->getMessage()], 500);
        }
    }


    /**
     * show
     *
     * @param  mixed $id
     * @return void
     */
    public function show($id)
    {
        try {
            $table = Table::find($id);
            return response()->json(['status' => true, 'message' => 'Table fetched successfully', 'table' => $table], 200);
        } catch (\Exception $e) {
            return response()->json(['status' => false, 'message' => 'Table fetching failed', 'errors' => $e->getMessage()], 500);
        }
    }

    /**
     * update
     *
     * @param  mixed $request
     * @param  mixed $id
     * @return void
     */
    public function update(Request $request, $id)
    {
        try {
            $table = Table::find($id);
            $table->update($request->all());
            return response()->json(['status' => true, 'message' => 'Table updated successfully', 'table' => $table], 200);
        } catch (\Exception $e) {
            return response()->json(['status' => false, 'message' => 'Table updating failed', 'errors' => $e->getMessage()], 500);
        }
    }

    /**
     * store
     *
     * @param  mixed $request
     * @return void
     */
    public function store(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'name' => 'required|string|max:255',
                'status' => 'nullable|string|in:active,empty,reserved,waiting',
            ]);

            if ($validator->fails()) {
                return response()->json(['status' => false, 'message' => 'Validation failed', 'errors' => $validator->errors()], 422);
            }

            $table = Table::create($request->all());
            return response()->json(['status' => true, 'message' => 'Table created successfully', 'data' => $table], 200);
        } catch (\Exception $e) {
            return response()->json(['status' => false, 'message' => 'Table creation failed', 'errors' => $e->getMessage()], 500);
        }
    }

    /**
     * destroy
     *
     * @param  mixed $id
     * @return void
     */
    public function destroy($id)
    {
        try {
            DB::beginTransaction();

            $table = Table::findOrFail($id);

            // İlişkili kayıtları sırayla silelim
            foreach ($table->orders as $order) {
                // Önce kitchen orders
                KitchenOrder::where('order_id', $order->id)->delete();

                // Sonra order items
                OrderItem::where('order_id', $order->id)->delete();

                // Ödemeleri sil
                Payment::where('order_id', $order->id)->delete();
            }

            // Orders tablosundaki kayıtları sil
            Order::where('table_id', $id)->delete();

            // QR siparişleri sil
            QrOrder::where('table_id', $id)->delete();

            // Garson çağrılarını sil
            WaiterCall::where('table_id', $id)->delete();

            // En son masayı sil
            $table->delete();

            DB::commit();

            return response()->json([
                'status' => true,
                'message' => 'Masa başarıyla silindi'
            ], 200);

        } catch (\Exception $e) {
            DB::rollBack();
            return response()->json([
                'status' => false,
                'message' => 'Masa silinemedi',
                'error' => $e->getMessage()
            ], 500);
        }
    }

    public function getActiveTables()
    {
        try {
            $tables = Table::select('id', 'name', 'status')
                ->where('status', '!=', 'deleted')
                ->orderBy('name')
                ->get();

            return response()->json([
                'status' => true,
                'tables' => $tables
            ]);
        } catch (\Exception $e) {
            \Log::error('Masa listesi getirme hatası: ' . $e->getMessage());
            return response()->json([
                'status' => false,
                'message' => 'Masalar getirilemedi',
                'error' => $e->getMessage()
            ], 500);
        }
    }
}
