'use client'

import { useEffect, useState } from 'react'
import DashboardLayout from '@/components/layout/DashboardLayout'
import { FiDollarSign, FiCalendar, FiFilter } from 'react-icons/fi'
import { paymentService } from '@/services/api'
import { useUser } from '@/contexts/UserContext'
import DatePicker from 'react-datepicker'
import 'react-datepicker/dist/react-datepicker.css'
import { getDate } from '@/config/tableConfig'

export default function PaymentsPage() {
  const { user } = useUser()
  const [payments, setPayments] = useState<any[]>([])
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState<string | null>(null)
  const [startDate, setStartDate] = useState<Date | null>(null)
  const [endDate, setEndDate] = useState<Date | null>(null)
  const [currentPage, setCurrentPage] = useState(1)
  const [totalPages, setTotalPages] = useState(1)
  const [itemsPerPage, setItemsPerPage] = useState(10)

  const fetchPayments = async (start?: Date | null, end?: Date | null) => {
    try {
      setLoading(true)
      const params = {
        start_date: start?.toISOString().split('T')[0],
        end_date: end?.toISOString().split('T')[0],
        page: currentPage,
        limit: itemsPerPage
      }
      
      const response = await paymentService.index(
        user?.token || '',
        start && end ? params : {...params, page: 1}
      )
      
      setPayments(response.data?.data || [])
      setTotalPages(response.data?.total_pages || 1)
      setCurrentPage(response.data?.current_page || 1)
      setError(null)
    } catch (err: any) {
      setError(err.response?.data?.message || 'Ödemeler yüklenirken hata oluştu')
      setPayments([])
    } finally {
      setLoading(false)
    }
  }

  useEffect(() => {
    if (user?.token) {
      fetchPayments(startDate, endDate)
    }
  }, [user?.token, startDate, endDate])

  const handlePageChange = (newPage: number) => {
    if(newPage >= 1 && newPage <= totalPages) {
      setCurrentPage(newPage)
    }
  }

  const clearFilters = () => {
    setStartDate(null)
    setEndDate(null)
    setCurrentPage(1)
  }

  if (loading) {
    return (
      <DashboardLayout>
        <div className="animate-pulse space-y-6">
          <div className="h-10 bg-slate-200 dark:bg-slate-700 rounded-xl w-64" />
          <div className="grid gap-4">
            {[...Array(5)].map((_, i) => (
              <div key={i} className="h-16 bg-slate-100 dark:bg-slate-800 rounded-xl" />
            ))}
          </div>
        </div>
      </DashboardLayout>
    )
  }

  if (error) {
    return (
      <DashboardLayout>
        <div className="text-red-500 dark:text-red-400 p-4 text-center">
          {error}
        </div>
      </DashboardLayout>
    )
  }

  return (
    <DashboardLayout>
      <div className="space-y-6">
        {/* Başlık ve Filtreleme */}
        <div className="flex flex-col sm:flex-row sm:items-center justify-between gap-4">
          <div>
            <h1 className="text-2xl font-bold text-slate-800 dark:text-white">
              Ödeme Geçmişi
            </h1>
            <p className="mt-1 text-sm text-slate-500 dark:text-slate-400">
              Tüm ödeme işlemlerinizin listesi
            </p>
          </div>
          
          <div className="flex items-center gap-3 bg-white dark:bg-slate-800 p-4 rounded-xl shadow-sm border border-slate-200/50 dark:border-slate-700/50">
            <FiFilter className="w-5 h-5 text-slate-500 dark:text-slate-400" />
            <DatePicker
              selected={startDate}
              onChange={date => setStartDate(date)}
              selectsStart
              startDate={startDate}
              endDate={endDate || undefined}
              placeholderText="Başlangıç Tarihi"
              className="w-32 px-3 py-2 rounded-lg border border-slate-200/50 dark:border-slate-700/50 bg-transparent text-sm"
            />
            <span className="text-slate-400">-</span>
            <DatePicker
              selected={endDate}
              onChange={date => setEndDate(date)}
              selectsEnd
              startDate={startDate}
              endDate={endDate}
              minDate={startDate || undefined}
              placeholderText="Bitiş Tarihi"
              className="w-32 px-3 py-2 rounded-lg border border-slate-200/50 dark:border-slate-700/50 bg-transparent text-sm"
            />
          </div>
        </div>

        {/* Ödeme Listesi Tablosu */}
        <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm rounded-3xl shadow-lg border border-slate-200/50 dark:border-slate-700/50">
          <div className="overflow-x-auto">
            <table className="w-full">
              <thead>
                <tr className="border-b border-slate-200/50 dark:border-slate-700/50">
                  <th className="text-left px-6 py-4 text-sm font-semibold text-slate-800 dark:text-slate-200">
                    Masa
                  </th>
                  <th className="text-left px-6 py-4 text-sm font-semibold text-slate-800 dark:text-slate-200">
                    Tutar
                  </th>
                  <th className="text-left px-6 py-4 text-sm font-semibold text-slate-800 dark:text-slate-200">
                    Personel
                  </th>
                  <th className="text-left px-6 py-4 text-sm font-semibold text-slate-800 dark:text-slate-200">
                    Ödeme Tarihi
                  </th>
                  <th className="text-left px-6 py-4 text-sm font-semibold text-slate-800 dark:text-slate-200">
                    Durum
                  </th>
                </tr>
              </thead>
              <tbody>
                {payments.map((payment) => (
                  <tr 
                    key={payment.id}
                    className="border-b border-slate-200/50 dark:border-slate-700/50 hover:bg-slate-50/50 dark:hover:bg-slate-700/20 transition-colors"
                  >
                    <td className="px-6 py-4">
                      <div className="flex items-center gap-3">
                        <div className="w-8 h-8 rounded-lg bg-gradient-to-r from-fuchsia-500 to-purple-600 flex items-center justify-center">
                          <FiDollarSign className="w-4 h-4 text-white" />
                        </div>
                        <span className="font-medium text-slate-800 dark:text-slate-100">
                          {payment.table?.name}
                        </span>
                      </div>
                    </td>
                    <td className="px-6 py-4 text-slate-800 dark:text-slate-200">
                      ₺{parseFloat(payment.amount).toFixed(2)}
                    </td>
                    <td className="px-6 py-4 text-slate-800 dark:text-slate-200">
                      {payment.user?.name || 'Personel Bilgisi Yok'}
                    </td>
                    <td className="px-6 py-4 text-slate-600 dark:text-slate-300">
                      {getDate(payment.payment_date)}
                    </td>
                    <td className="px-6 py-4">
                      <span className={`inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-green-100 dark:bg-green-900/50 text-green-600 dark:text-green-400`}>
                     Tamamlandı
                      </span>
                    </td>
                  </tr>
                ))}
              </tbody>
            </table>
          </div>
          
          {/* Sayfalama kontrolleri */}
          <div className="flex items-center justify-between px-6 py-4 border-t border-slate-200/50 dark:border-slate-700/50">
            <div className="text-sm text-slate-600 dark:text-slate-400">
              Toplam {payments.length} kayıt • Sayfa {currentPage}/{totalPages}
            </div>
            <div className="flex gap-2">
              <button
                onClick={() => handlePageChange(currentPage - 1)}
                disabled={currentPage === 1}
                className="px-3  dark:text-white py-1.5 text-sm rounded-lg border border-slate-200/50 dark:border-slate-700/50 bg-transparent disabled:opacity-50 disabled:cursor-not-allowed"
              >
                Önceki
              </button>
              
              {Array.from({length: totalPages}, (_, i) => i + 1).map(page => (
                <button
                  key={page}
                  onClick={() => handlePageChange(page)}
                  className={`px-3 py-1.5 text-sm rounded-lg ${
                    page === currentPage 
                      ? 'bg-fuchsia-500 text-white' 
                      : 'border border-slate-200/50 dark:border-slate-700/50'
                  }`}
                >
                  {page}
                </button>
              ))}
              
              <button
                onClick={() => handlePageChange(currentPage + 1)}
                disabled={currentPage === totalPages}
                className="px-3 dark:text-white py-1.5 text-sm rounded-lg border border-slate-200/50 dark:border-slate-700/50 bg-transparent disabled:opacity-50 disabled:cursor-not-allowed"
              >
                Sonraki
              </button>
            </div>
          </div>
        </div>
      </div>
    </DashboardLayout>
  )
} 