import axios from 'axios'

const API_URL = process.env.NEXT_PUBLIC_API_URL
const API_VERSION = process.env.NEXT_PUBLIC_API_VERSION

export const api = axios.create({
  baseURL: `${API_URL}/${API_VERSION}`,
  headers: {
    'Content-Type': 'application/json',
  }
})

// Demo mod kontrolü 
const checkDemoMode = () => {
  if (process.env.NEXT_PUBLIC_DEMO_MODE === 'true') {
    alert('Bu işlem demo modunda yapılamaz')
    throw new Error('Demo modda bu işlem gerçekleştirilemez')
  }
}

// Masa servisleri
export const tableService = {
  index: (token: string) => {
    return api.get('/tables/index', {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  show: (id: string, token: string) => {
    return api.get(`/tables/show/${id}`, {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  create: (name: string, token: string) => {
    checkDemoMode()
    return api.post('/tables/store', { name }, {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  update: (id: string, name: string, token: string) => {
    checkDemoMode()
    return api.put(`/tables/update/${id}`, { name }, {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  destroy: (id: string, token: string) => {
    checkDemoMode()
    return api.delete(`/tables/destroy/${id}`, {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  addOrder: (id: string, products: any[], token: string) => {
    checkDemoMode()
    return api.post(`/tables/${id}/add-order`, { products }, {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  checkStatus: (id: string, token: string) => {
    return api.get(`/tables/${id}/check-status`, {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  orderDetails: (tableId: string, token: string) => {
    return api.get(`/tables/${tableId}/order-details`, {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  takePayment: (tableId: number, token: string) => {
    checkDemoMode()
    return api.post(`/tables/${tableId}/take-payment`, {}, {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  checkInactive: (token: string) => {
    return api.get('/tables/check-inactive', {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  transfer: (fromTableId: string, toTableId: string, token: string) => {
    checkDemoMode()
    return api.post(`/tables/${fromTableId}/transfer/${toTableId}`, {}, {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  receipt: (id: string, token: string) => {
    return api.get(`/tables/orders/${id}/receipt`, {
      headers: {
        'Authorization': `Bearer ${token}`,
      },
      responseType: 'blob'
    })
  }
}

export const authService = {
  login: (email: string, password: string) => {
    return api.post('/login', { email, password })
  }
}

export const categoryService = {
  index: (token: string) => {
    return api.get('/categories/index', {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  store: (name: string, token: string) => {
    checkDemoMode()
    return api.post('/categories/store', { name }, {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  destroy: (id: string, token: string) => {
    checkDemoMode()
    return api.delete(`/categories/destroy/${id}`, {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  show: (id: string, token: string) => {
    return api.get(`/categories/show/${id}`, {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  update: (id: string, name: string, token: string) => {
    checkDemoMode()
    return api.post(`/categories/update/${id}`, { name }, {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  }
}

export const productService = {
  index: (token: string) => {
    return api.get('/products/index', {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  store: (formData: FormData, token: string) => {
    checkDemoMode()
    return api.post('/products/store', formData, {
      headers: {
        'Authorization': `Bearer ${token}`,
        'Content-Type': 'multipart/form-data'
      }
    })
  },
  show: (id: string, token: string) => {
    return api.get(`/products/show/${id}`, {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  destroy: (id: string, token: string) => {
    checkDemoMode()
    return api.delete(`/products/destroy/${id}`, {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  update: (id: string, formData: FormData, token: string) => {
    checkDemoMode()
    return api.post(`/products/update/${id}`, formData, {
      headers: {
        'Authorization': `Bearer ${token}`,
        'Content-Type': 'multipart/form-data'
      }
    })
  },

}

export const reportService = {
  static: (token: string, role: string) => {
    return api.get('/reports/statistics', {
      headers: {
        'Authorization': `Bearer ${token}`,
        'role': role
      }
    })
  }
}

export const qrOrderService = {
  index: (token: string) => {
    return api.get('/qr-orders/pending', {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  approve: (id: string, token: string) => {
    checkDemoMode()
    return api.post(`/qr-orders/${id}/approve`, {}, {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  reject: (id: string, token: string) => {
    checkDemoMode()
    return api.post(`/qr-orders/${id}/reject`, {}, {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  }
}

export const waiterService = {
  index: () => {
    return api.get('/waiter-calls/pending')
  }
}

export const kitchenService = {
  index: (token: string) => {
    return api.get('/kitchen/index', {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  },
  complete: (orderId: number, token: string) => {
    checkDemoMode()
    return api.post(`/kitchen/complete/${orderId}/status`, { status: 'completed' }, {
      headers: {
        'Authorization': `Bearer ${token}`
      }
    })
  }
}

export const paymentService = {
  index: (token: string, params?: { start_date?: string; end_date?: string }) => {
    return api.get('/payments/index', {
      headers: {
        'Authorization': `Bearer ${token}`
      },
      params: params
    })
  }
}

export const staffService = {
  create: (data: {
    name: string
    email: string
    password: string
    password_confirmation: string

  }, token: string) => {
    checkDemoMode()
    return api.post('/staff/store', data, {
      headers: {
        Authorization: `Bearer ${token}`
      }
    })
  },
  list: (token: string) => {
    return api.get('/staff/list', {
      headers: {
        Authorization: `Bearer ${token}`
      }
    })
  },
  destroy: (id: string, token: string) => {
    checkDemoMode()
    return api.post(`/admin/staff/destroy/${id}`, {
      headers: {
        Authorization: `Bearer ${token}`
      }
    })
  }
}

interface Statistics {
  daily_income: {
    amount: number;
    increase_percentage: number;
  };
  monthly_income: {
    amount: number;
    increase_percentage: number;
  };
  orders: {
    total: number;
    monthly: number;
  };
  top_selling_today: {
    name: string;
    price: number;
    total_quantity: number;
    total_amount: number;
  }[];
}

export const getStatistics = async (): Promise<Statistics> => {
  const response = await api.get('/statistics');
  return response.data.data;
};

export const logout = async (token: string) => {
  return api.post('/logout', {
    headers: {
      Authorization: `Bearer ${token}`
    }
  })
}
