import { create } from 'zustand'
import { persist } from 'zustand/middleware'

interface Notification {
  id: number
  message: string
  timestamp: number
  type: 'waiter' | 'system'
  read: boolean
}

interface NotificationStore {
  message: string | null
  notifications: Notification[]
  soundEnabled: boolean
  showNotification: (message: string, type?: 'waiter' | 'system') => void
  hideNotification: () => void
  toggleSound: () => void
  markAsRead: (id: number) => void
  clearNotifications: () => void
}

export const useNotificationStore = create<NotificationStore>()(
  persist(
    (set) => ({
      message: null,
      notifications: [],
      soundEnabled: true,
      showNotification: (message, type = 'system') => {
        const newNotification = {
          id: Date.now(),
          message,
          timestamp: Date.now(),
          type,
          read: false
        }
        
        set((state) => ({
          message,
          notifications: [newNotification, ...state.notifications].slice(0, 10)
        }))

        setTimeout(() => {
          set({ message: null })
        }, 10000)
      },
      hideNotification: () => set({ message: null }),
      toggleSound: () => set((state) => ({ soundEnabled: !state.soundEnabled })),
      markAsRead: (id) => set((state) => ({
        notifications: state.notifications.map(n => 
          n.id === id ? { ...n, read: true } : n
        )
      })),
      clearNotifications: () => set({ notifications: [] })
    }),
    {
      name: 'notification-store'
    }
  )
) 